@@ -61,7 +61,7 @@
 #define KPIPEWIREDMABUF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPIPEWIREDMABUF_NO_DEPRECATED
-#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b07
+#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60005
 #endif
 #ifdef KPIPEWIREDMABUF_NO_DEPRECATED_WARNINGS
 #  define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0
@@ -71,12 +71,12 @@
 #  ifdef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0x51b07
+#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0x60005
 #  endif
 #endif
 
 #ifndef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
-#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
+#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60000
 #endif
 
 #ifdef KPIPEWIREDMABUF_DEPRECATED
